
{% load static %}
<script src="{% static 'django-tiles-gl/maplibre/maplibre-gl.js' %}" type='text/javascript'></script>
<link href="{% static 'django-tiles-gl/maplibre/maplibre-gl.css' %}" rel='stylesheet' type='text/css' />